#
# spec file for package adolc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libadolc2
Name:           adolc
Version:        2.7.2
Release:        4.1
Summary:        Algorithmic Differentiation Library for C/C++
License:        EPL-1.0 OR GPL-2.0-or-later
URL:            https://github.com/coin-or/ADOL-C
Source0:        https://github.com/coin-or/ADOL-C/archive/releases/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# from https://github.com/coin-or/ADOL-C/pull/47.patch
Patch1:         handle-lib64-for-riscv64.patch
BuildRequires:  ColPack-devel
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
%endif

%description
ADOL-C (Automatic Differentiation by OverLoading in C++) facilitates
the evaluation of first and higher derivatives of vector functions
written in C or C++.

%package -n %{lname}
Summary:        Algorithmic Differentiation Library for C/C++

%description -n %{lname}
ADOL-C (Automatic Differentiation by OverLoading in C++) facilitates
the evaluation of first and higher derivatives of vector functions
written in C or C++. The resulting derivative evaluation routines may
be called from C/C++, Fortran, or any other language that can be
linked with C.

The numerical values of derivative vectors are obtained free of
truncation errors at a small multiple of the run time and randomly
accessed memory of the given function evaluation program.

%package devel
Summary:        Development files for the Algorithmic Differentiation Library
Requires:       %{lname} = %{version}

%description devel
This package provides the development environment for ADOL-C
(Automatic Differentiation by OverLoading in C++).

%package doc
Summary:        Documentation for the C/C++ Algorithmic Differentiation Library
BuildArch:      noarch

%description doc
This package provides the user's manual for ADOL-C.

%prep
%autosetup -p1 -n ADOL-C-releases-%{version}

%build
# autoreconf -v --install --force
%configure
%make_build
# cd ADOL-C/doc
# for ((i=0; i < 3; i++)); do
#    pdflatex adolc-manual.tex &>/dev/null
# done

%install
%make_install
find %{buildroot} -type f "(" -name "*.a" -o -name "*.la" ")" -delete -print

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}
%license LICENSE
%{_libdir}/libadolc.so.*

%files devel
%dir %{_includedir}/adolc
%dir %{_includedir}/adolc/drivers
%dir %{_includedir}/adolc/internal
%dir %{_includedir}/adolc/lie
%dir %{_includedir}/adolc/sparse
%dir %{_includedir}/adolc/tapedoc
%{_includedir}/adolc/*.h
%{_includedir}/adolc/drivers/*.h
%{_includedir}/adolc/internal/*.h
%{_includedir}/adolc/lie/drivers.h
%{_includedir}/adolc/sparse/*.h
%{_includedir}/adolc/tapedoc/*.h
%{_libdir}/libadolc.so
%{_libdir}/pkgconfig/adolc.pc

%files doc
%doc README AUTHORS BUGS TODO
%doc ADOL-C/doc/adolc-manual.pdf
%doc ADOL-C/doc/short_ref.pdf
%license LICENSE

%changelog
* Sat Apr 12 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Drop baselibs.conf, 32bit support is not needed anymore
* Mon Feb 24 2025 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile and avoid bashisms (commented, but still)
- Remove em dashes from summaries
* Fri Oct  7 2022 Dirk Müller <dmueller@suse.com>
- add handle-lib64-for-riscv64.patch
* Fri Jul 24 2020 Matthias Eliasson <elimat@opensuse.org>
- update to version 2.7.2
- upstream have changed location to github, change URLs accordingly
- run spec-cleaner
* Wed Aug  8 2018 jengelh@inai.de
- Repair broken description ("the package ADOL-C [end of sentence]")
- Move main description to shared library subpackage since that
  will be installed most of the time (if and when some part of
  adolc is installed at all).
* Mon Jun 11 2018 adam.majer@suse.de
- Install license using %%license
- Install documentation using %%doc instead of manually
- Cleanup long description by only having one verbose copy in long
  description
- spec file cleanup
* Sun Jun 10 2018 antoine.belvire@opensuse.org
- Update to version 2.6.3:
  * Fix bug in memory deallocation in taylor.c.
  * Reduced interface directional active gradient.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Sep  4 2016 kkhere.geo@gmail.com
- upadte to version 2.6.2
  * fixes for corner case crashes
* Thu Jun  9 2016 kkhere.geo@gmail.com
- update to version 2.6.1
  * small assorted bugfixes
* Mon Jan 11 2016 kkhere.geo@gmail.com
- update to version 2.6.0
  * Drivers for Lie-Derivatives (by Mirko Franke).
  * New extended interface for external functions, which may be used to
    interface to source transformation tools. Previous interface remains
    intact too.
  * Driver to compute the abs-normal form of piecewise smooth functions.
  * Mechanism to compute sparsity pattern of abs-normal form.
  * Interface to define passive parameters that can be changed before each
    trace interpretation. Major use case is Lagrange Multipliers.
  * Interface to AdjoinableMPI improved and debugged.
  * ADOL-C now uses boost (>= 1.54) for increased execution speed if
    detected during build.
  * ADOL-C and all applications must be compiled using a C++11 compiler.
  * Many, many odd and sundry bugfixes.
  - added BuildRequires: boost-devel
* Wed Apr 22 2015 mpluskal@suse.com
- Use source for url
- Do not pull autotools when they are not used
- Cleanup spec-file with spec-cleaner
* Tue Aug 19 2014 kkhere.geo@gmail.com
- Update to upstream version 2.5.2
  * incorporated bugfixes since 2.5.1
* Sun Aug 17 2014 kkhere.geo@gmail.com
- Update to upstream version 2.5.1
  * Lots of bugfixes
- Added a couple of post release bugfixes from trunk
- Removed patch incorporated upstream
  * no-return-in-non-void-adouble_tl_cpp.patch
* Tue Feb 25 2014 kkhere.geo@gmail.com
- Update to upstream version 2.5.0
  * An overhaul of the internal memory management to make it
    more efficient
  * Support for the AdjoinableMPI API (thanks to Jean Utke)
  * Overhaul of the external functions interface (thanks to Jean Utke)
  * Support for piecewise linearizations of piecewise smooth functions
  * Support for pkg-config (thanks to Oliver Sander)
  * Computations on the NVIDIA-GPU in forward mode using CUDA
  * Overhaul of the traceless forward mode.
  * Support for sparsity in traceless forward mode.
  * Fixes in higher order tensor propagation
  * Fix a function name conflict
    address() -> tensor_address()
  * Various other small misceleneous fixes
- Patch added
  * no-return-in-non-void-adouble_tl_cpp.patch
* Tue Mar 19 2013 kkhere.geo@gmail.com
- Update to upstream version 2.4.1
  * list of changes in the release announcement
    see http://list.coin-or.org/pipermail/adol-c/2013-January/000882.html
    and http://list.coin-or.org/pipermail/adol-c/2013-March/000887.html
* Sat Sep 15 2012 scorot@free.fr
- fix build for SLE 11 SP2
* Thu Mar 22 2012 kkhere.geo@gmail.com
- Update to new upsteam version 2.3.0
  * list of changes in the release announcement
    see http://list.coin-or.org/pipermail/adol-c/2012-March/000804.html
  * licensing modified
    see http://list.coin-or.org/pipermail/adol-c/2012-March/000805.html
- Update License tag in accordance with above change
- Remove ColPack, it can be packaged in its own package with v1.0.6
- Add a BuildRequires for ColPack-devel
* Fri Feb 17 2012 kkhere.geo@gmail.com
- Change License tag to reflect discussion in bnc#739158
* Mon Dec 19 2011 Rene.vanPaassen@gmail.com
- Corrected group tags to proper categories
* Fri Dec 16 2011 Rene.vanPaassen@gmail.com
- need Group: tags for SLE_11 and SLE_11_SP1, if all tags are equal,
  the format_spec_file service is so NICE (not!) to remove subpackage
  group tags. the doc package needs a Group: Documentation tag
  (guidelines), and then, fortunately, format_spec_file leaves
  us alone
* Thu Dec 15 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Oct  6 2011 kkhere.geo@gmail.com
- update Colpack to new version 1.0.4
  * some memory allocation bugfixes
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%__cc, %%__cxx macros
* Fri Sep 16 2011 jengelh@medozas.de
- Implement baselibs for package; remove redundant tags/sections
* Thu Jun  9 2011 kkhere.geo@gmail.com
- update to upstream release 2.2.1
  * allow reading hexadecimal and octal numbers in .adolcrc
  * bugfix for direct reverse callsequence after trace
  * reimplemented nonl_dom as arrays instead of linked lists
* Tue Apr 12 2011 kkhere.geo@gmail.com
- update to upstream release 2.2.0
  * numerous bugfixes
  * memory leak fixes
  * new revamped internal memory manager
* Thu Nov 11 2010 kshitij@math.upb.de
- update to upstream release 2.1.12
  * bug fix in tapeless mode log and sqrt
  * allow changing TAPE_DIR at runtime
  * allow direct coupling with IpOpt
* Fri Oct 15 2010 coolo@novell.com
- remove the macro from the version tag
* Mon Oct 11 2010 kshitij@math.upb.de
- update to svn trunk rev 175
  * build fixes for windows and linux
  * bug fixes
  * ISO C99 compatibility
- stoped building 32bit packages on 64bit arch
* Sat Sep 25 2010 kshitij@math.upb.de
- Fix building on older distros
* Thu Sep 23 2010 kkhere.geo@gmail.com
- correct file ownership
* Thu Sep 23 2010 kshtiij@math.upb.de
- use LIBS instead of LDFLAGS to check for ColPack
  the order seems to matter in the build service environment
* Thu Sep 23 2010 kshitij@math.upb.de
- initial package for version 2.1.10
